==> moodle-1.5-mysql.tgz: moodle/lang/fi/error.php <==
<?PHP // $Id$ 
      // error.php - created with Moodle 1.5 + (2005060201)


$string['adminprimarynoedit'] = 'Pkyttjn tietoja eivt voi muut muokata';
$string['confirmsesskeybad'] = 'Valitettavasti istuntoavaintasi ei voitu varmistaa toteuttaaksesi tmn toiminnon. Tm turvaominaisuus ehkisee vahingossa tapahtuvaa tai tahallista ilkivaltaista trkeiden toimintojen suoritusta nimellsi. Varmista, ett todella haluat suorittaa tmn toiminnon.';
$string['coursegroupunknown'] = 'Ryhm $a vastaavaa kurssia  ei ole mritetty.';
$string['erroronline'] = 'Virhe rivill $a';
$string['fieldrequired'] = 'Kentt \"$a\" vaaditaan';
$string['filenotfound'] = 'Pahus, pyydetty tiedosta ei lydy';
$string['groupalready'] = 'Kyttj kuuluu jo ryhmn $a';
$string['groupunknown'] = 'Ryhm $a ei kuulu  kurssille';
$string['invalidfieldname'] = '\"$a\" ei ole kelvollinen kentn nimi';
$string['missingfield'] = 'Kentt \"$a\" puuttuu';
$string['modulerequirementsnotmet'] = 'Moduulia \"$a->modulename\" ($a->moduleversion) ei voitu asentaa. Se vaatii uudemman version Moodlesta (Kytt versiota $a->currentmoodle. Tarvitset version $a->requiremoodle).';
$string['notavailable'] = 'Ominaisuus ei ole tll hetkell kytettviss.';
$string['onlyeditown'] = 'Vait muokata vain omia tietojasi';
$string['processingstops'] = 'Kasittely loppuu thn. Loput tietueet on ksittelemtt.';
$string['restricteduser'] = 'Kyttjtilisi \"$a\" on rajoitettu toiminnon osalta.';
$string['sessionerroruser'] = 'Istuntosi on vanhentunut. Ole hyv ja kirjaannu uudelleen.';
$string['sessionipnomatch'] = 'Valitettavasti IP numerosi nytt muuttuneen siit, kun aluksi kirjauduit sisn. Tm turvatoiminto est hakkereita varastamasta identiteettisi sill vlin kun olet rekisterityneen tll sivulla. Normaalien kyttjien ei pitisi nhd tt viesti- pyyd sivuston hallinnolta apua.';
$string['unknowncourse'] = 'Tuntematon kurssi nimeltn \"$a\"';
$string['usernotaddederror'] = 'Kyttj \"$a\" ei listty - tuntematon virhe';
$string['usernotaddedregistered'] = 'Kyttj \"$a\" ei listty - on jo rekisterity';
$string['usernotavailable'] = 'Pahus, et voi tarkastella kyseisen kyttjn tietoja';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/fi/error.php <==
<?PHP // $Id$ 
      // error.php - created with Moodle 1.5.2 + (2005060222)


$string['adminprimarynoedit'] = 'Muut eivt voi muokata pasiallista yllpitj';
$string['confirmsesskeybad'] = 'Valitettavasti istuntoavaintasi ei voitu varmistaa toteuttaaksesi tmn toiminnon. Tm turvaominaisuus ehkisee vahingossa tapahtuvaa tai tahallista ilkivaltaista trkeiden toimintojen suoritusta nimellsi. Varmista, ett todella haluat suorittaa tmn toiminnon.';
$string['coursegroupunknown'] = 'Ryhm $a vastaavaa kurssia  ei ole mritetty.';
$string['erroronline'] = 'Virhe rivill $a';
$string['fieldrequired'] = 'Kentt \"$a\" vaaditaan';
$string['filenotfound'] = 'Pahus, pyydetty tiedosta ei lydy';
$string['groupalready'] = 'Kyttj kuuluu jo ryhmn $a';
$string['groupunknown'] = 'Ryhm $a ei kuulu  kurssille';
$string['invalidfieldname'] = '\"$a\" ei ole kelvollinen kentn nimi';
$string['missingfield'] = 'Kentt \"$a\" puuttuu';
$string['modulerequirementsnotmet'] = 'Moduulia \"$a->modulename\" ($a->moduleversion) ei voitu asentaa. Se vaatii uudemman version Moodlesta (Kytt versiota $a->currentmoodle. Tarvitset version $a->requiremoodle).';
$string['notavailable'] = 'Ominaisuus ei ole tll hetkell kytettviss.';
$string['onlyeditown'] = 'Voit muokata vain omia tietojasi.';
$string['processingstops'] = 'Ksittely loppuu thn. Jljelle jneet merkinnt jtetn huomiotta.';
$string['restricteduser'] = 'Kyttjtilisi \"$a\" on rajoitettu toiminnon osalta.';
$string['sessionerroruser'] = 'Istuntosi on kirjautunut ulos aikarajan takia. Kirjaudu uudestaan sisn.';
$string['sessionipnomatch'] = 'Valitettavasti IP numerosi nytt muuttuneen siit, kun aluksi kirjauduit sisn. Tm turvatoiminto est hakkereita varastamasta identiteettisi sill vlin kun olet rekisterityneen tll sivulla. Normaalien kyttjien ei pitisi nhd tt viesti- pyyd sivuston hallinnolta apua.';
$string['unknowncourse'] = 'Tuntematon kurssi nimeltn \"$a\"';
$string['usernotaddederror'] = 'Kyttj \"$a\" ei listty - tuntematon virhe';
$string['usernotaddedregistered'] = 'Kyttj \"$a\" ei listty - on jo rekisterity';
$string['usernotavailable'] = 'Pahus, et voi tarkastella kyseisen kyttjn tietoja';

?>
